use std::collections::HashMap;

pub struct SitemapEntry {
    pub location: String,
    pub lastmod: chrono::DateTime<chrono::Utc>,
}

impl SitemapEntry {
    fn to_item(&self) -> String {
        format!(
            r#"
            <url>
                <loc>{}</loc>
                <lastmod>{}</lastmod>
            </url>
        "#,
            self.location,
            self.lastmod.to_rfc3339(),
        )
    }
}

pub fn generate_sitemap(entries: &HashMap<String, SitemapEntry>) -> String {
    let urls = entries
        .values()
        .into_iter()
        .map(|entry| entry.to_item())
        .collect::<String>();
    format!(
        r#"
           <!-- Generated by Kyouma 1.0.0-SE -->
           <urlset xmlns="http://www.sitemaps.org/schemas/sitemap/0.9">
            {}
           </urlset>
        "#,
        urls
    )
}

pub fn get_static_pages(entries: &mut HashMap<String, SitemapEntry>, web_url: &String) {
    entries.insert(
        (entries.len() + 1).to_string(),
        SitemapEntry {
            location: web_url.clone(),
            lastmod: chrono::Utc::now(),
        },
    );
    entries.insert(
        (entries.len() + 1).to_string(),
        SitemapEntry {
            location: format!("{}/posts", web_url),
            lastmod: chrono::Utc::now(),
        },
    );
    entries.insert(
        (entries.len() + 1).to_string(),
        SitemapEntry {
            location: format!("{}/projects", web_url),
            lastmod: chrono::Utc::now(),
        },
    );
}
