use crate::utils::{
    request::{Request, Response},
    task_log,
    {upload::S3ClientConfig, *},
};

pub fn register(pool: &sqlx::Pool<sqlx::Postgres>) {
    let p = pool.clone();
    tokio::spawn(async move {
        let _ = upload_sitemap(&p).await;
    });
}

async fn upload_sitemap(
    pool: &sqlx::Pool<sqlx::Postgres>,
) -> Result<(), Box<dyn std::error::Error>> {
    // TODO:: get sitemap and upload it to bucket??
    task_log::start(3, pool).await?;

    // get request and request the things
    let request = Request::new();
    let sitemap_url = format!("{}/posts/sitemap", request.base_url);
    let sitemap_result = request.request_url::<String>(&sitemap_url).await;

    // upload the sucker to obj storage
    if let Response::Xml(sitemap) = sitemap_result {
        let client_config = S3ClientConfig::from_env().unwrap();
        let s3_client = upload::create_s3_client(&client_config).await.unwrap();
        let _ = upload::upload(
            &s3_client,
            client_config.bucket.as_str(),
            "sitemap.xml",
            sitemap.as_str(),
        )
        .await;
        println!("Finished uploading sitemap!");
    }

    Ok(())
}
