# This flake was initially generated by fh, the CLI for FlakeHub (version 0.1.10)
{
  # A helpful description of your flake
  description = "My personal website v2";

  # Flake inputs
  inputs = {
    flake-schemas.url = "https://flakehub.com/f/DeterminateSystems/flake-schemas/*.tar.gz";

    nixpkgs.url = "https://flakehub.com/f/NixOS/nixpkgs/*.tar.gz";

    rust-overlay = {
      url = "github:oxalica/rust-overlay";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    nix-deno = {
      url = "github:nekowinston/nix-deno";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  # Flake outputs that other flakes can use
  outputs = {
    self,
    flake-schemas,
    nixpkgs,
    rust-overlay,
    nix-deno,
  }: let
    # Nixpkgs overlays
    overlays = [
      nix-deno.overlays.default
      rust-overlay.overlays.default
      (final: prev: {
        rustToolchain = final.rust-bin.stable.latest.default.override {extensions = ["rust-src"];};
      })
    ];

    # Helpers for producing system-specific outputs
    supportedSystems = ["x86_64-linux" "aarch64-darwin" "x86_64-darwin" "aarch64-linux"];
    forEachSupportedSystem = f:
      nixpkgs.lib.genAttrs supportedSystems (system:
        f {
          pkgs = import nixpkgs {inherit overlays system;};
        });
  in {
    # Schemas tell Nix about the structure of your flake's outputs
    schemas = flake-schemas.schemas;

    # Development environments
    devShells = forEachSupportedSystem ({pkgs}: {
      default = pkgs.mkShell {
        # Pinned packages available in the environment
        packages = with pkgs; [
          rustToolchain
          rust-analyzer
          curl
          git
          jq
          wget
          nixpkgs-fmt
          openssl
          openssl.dev
          patchelf
          deno
          sqlx-cli
          cargo-watch
          cargo-chef
          valkey
          pkg-config-unwrapped
        ];

        # Environment variables
        env = {
          RUST_BACKTRACE = "1";
          RUST_SRC_PATH = "${pkgs.rustToolchain}/lib/rustlib/src/rust/library";
          PKG_CONFIG_PATH = "${pkgs.openssl.dev}/lib/pkgconfig";
          # ZELLIJ_CONFIG_FILE = "config.kdl";
          # PATH = "$PATH:$HOME/.local/share/nvim/mason/bin/deno";
        };
      };
    });
  };
}
